@@ -3,17 +3,17 @@ use 5.010;
 use Term::ANSIColor;
 use Data::Dumper;
 use Carp qw(confess);
-use FindBin qw($Bin);
-use lib "$Bin/../lib/";
+use FindBin qw($RealBin);
+use lib "$RealBin/../lib/";
 use FASTX::Reader;
 
 # Print splash screen
 print STDERR color('bold'), "TEST FASTA/FASTQ READER\n", color('reset');
 print STDERR color('bold'), "Read FASTA/FASTQ files, printing them back to the user\n", color('reset');
-print STDERR "Usage: $0 FILE1 FILE2 ... FILEn\n\n";
-
+print STDERR "Usage: $0 FILE1 FILE2 ... FILEn\n";
+print STDERR 'version: ', $FASTX::Reader::VERSION, "\n\n";
 # Read two samples files if the user didnt provide any filename
-push(@ARGV,"$Bin/../data/test.fastq", "$Bin/../data/test.fasta" )
+push(@ARGV,"$RealBin/../data/test.fastq", "$RealBin/../data/test.fasta" )
   unless ($ARGV[0]);
 
 foreach my $input_file (@ARGV) {
